@@ -12,10 +12,17 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/**
+ * SECTION:manette-device
+ * @short_description: An object representing a physical gamepad
+ * @title: ManetteDevice
+ * @See_also: #ManetteMonitor
+ */
+
 #include "manette-device-private.h"
 
 #include <errno.h>
@@ -44,7 +51,6 @@ struct _ManetteDevice
   ManetteMapping *mapping;
 
   struct ff_effect rumble_effect;
-  gint16 force_feedback_id;
 };
 
 G_DEFINE_TYPE (ManetteDevice, manette_device, G_TYPE_OBJECT)
@@ -61,9 +67,6 @@ enum {
 
 static guint signals[N_SIGNALS];
 
-#define GUID_DATA_LENGTH 8
-#define GUID_STRING_LENGTH 32 // (GUID_DATA_LENGTH * sizeof (guint16))
-
 typedef struct {
   ManetteDevice *self;
   guint          signal_id;
@@ -106,9 +109,9 @@ manette_device_event_signal_data_new (ManetteDevice *self,
 static void
 manette_device_event_signal_data_free (ManetteDeviceEventSignalData *signal_data)
 {
-  g_object_unref (signal_data->self);
-  manette_event_free (signal_data->event);
-  g_free (signal_data);
+  g_clear_object (&signal_data->self);
+  g_clear_pointer (&signal_data->event, manette_event_free);
+  g_clear_pointer (&signal_data, g_free);
 }
 
 static gboolean
@@ -149,7 +152,7 @@ is_game_controller (struct libevdev *device)
 {
   gboolean has_joystick_axes_or_buttons;
 
-  g_return_val_if_fail (device != NULL, FALSE);
+  g_assert (device != NULL);
 
   /* Same detection code as udev-builtin-input_id.c in systemd
    * joysticks don’t necessarily have buttons; e. g.
@@ -197,7 +200,7 @@ map_event (ManetteDevice *self,
 static void
 remove_event_source (ManetteDevice *self)
 {
-  g_return_if_fail (self != NULL);
+  g_assert (self != NULL);
 
   if (self->event_source_id < 0)
     return;
@@ -213,9 +216,8 @@ manette_device_finalize (GObject *object)
 
   close (self->fd);
   remove_event_source (self);
-  if (self->evdev_device != NULL)
-    libevdev_free (self->evdev_device);
-  g_free (self->guid);
+  g_clear_pointer (&self->evdev_device, libevdev_free);
+  g_clear_pointer (&self->guid, g_free);
   g_clear_object (&self->mapping);
 
   G_OBJECT_CLASS (manette_device_parent_class)->finalize (object);
@@ -331,54 +333,14 @@ manette_device_init (ManetteDevice *self)
   self->rumble_effect.id = -1;
 }
 
-static gchar
-guint16_get_hex (guint16 value,
-                 guint8  nibble)
-{
-  static const gchar hex_to_ascii_map[] = "0123456789abcdef";
-
-  g_assert (nibble < 4);
-
-  return hex_to_ascii_map[((value >> (4 * nibble)) & 0xf)];
-}
-
-static gchar *
-guint16s_to_hex_string (guint16 *data)
-{
-  gchar *result;
-  gint data_i;
-  gint result_i;
-  guint16 element;
-
-  result = g_malloc (GUID_STRING_LENGTH + 1);
-  result[GUID_STRING_LENGTH] = '\0';
-  for (data_i = 0, result_i = 0; data_i < GUID_DATA_LENGTH; data_i++) {
-    element = data[data_i];
-    result[result_i++] = guint16_get_hex (element, 1);
-    result[result_i++] = guint16_get_hex (element, 0);
-    result[result_i++] = guint16_get_hex (element, 3);
-    result[result_i++] = guint16_get_hex (element, 2);
-  }
-
-  return result;
-}
-
-// FIXME What about using 4 well crafted %x?
 static gchar *
 compute_guid_string (struct libevdev *device)
 {
-  guint16 guid_array[GUID_DATA_LENGTH] = { 0 };
-
-  guid_array[0] = (guint16) GINT_TO_LE (libevdev_get_id_bustype (device));
-  guid_array[1] = 0;
-  guid_array[2] = (guint16) GINT_TO_LE (libevdev_get_id_vendor (device));
-  guid_array[3] = 0;
-  guid_array[4] = (guint16) GINT_TO_LE (libevdev_get_id_product (device));
-  guid_array[5] = 0;
-  guid_array[6] = (guint16) GINT_TO_LE (libevdev_get_id_version (device));
-  guid_array[7] = 0;
-
-  return guint16s_to_hex_string (guid_array);
+  return g_strdup_printf ("%08x%08x%08x%08x",
+                          GINT_TO_BE (libevdev_get_id_bustype (device)),
+                          GINT_TO_BE (libevdev_get_id_vendor (device)),
+                          GINT_TO_BE (libevdev_get_id_product (device)),
+                          GINT_TO_BE (libevdev_get_id_version (device)));
 }
 
 static gdouble
@@ -391,7 +353,7 @@ centered_absolute_value (struct input_absinfo *abs_info,
   gint64 value_centered;
   gint64 divisor;
 
-  g_return_val_if_fail (abs_info != NULL, 0.0);
+  g_assert (abs_info != NULL);
 
   /* Adapt the value and the maximum to a minimum of 0. */
   max_normalized = ((gint64) abs_info->maximum) - abs_info->minimum;
@@ -476,16 +438,13 @@ on_evdev_event (ManetteDevice      *self,
 }
 
 static gboolean
-poll_events (GIOChannel   *source,
-             GIOCondition  condition,
-             gpointer      data)
+poll_events (GIOChannel    *source,
+             GIOCondition   condition,
+             ManetteDevice *self)
 {
-  ManetteDevice *self;
   struct input_event evdev_event;
 
-  self = MANETTE_DEVICE (data);
-
-  g_return_val_if_fail (MANETTE_IS_DEVICE (self), FALSE);
+  g_assert (MANETTE_IS_DEVICE (self));
 
   while (libevdev_has_event_pending (self->evdev_device))
     if (libevdev_next_event (self->evdev_device,
@@ -497,7 +456,7 @@ poll_events (GIOChannel   *source,
 }
 
 /**
- * manette_device_new: (skip):
+ * manette_device_new: (skip)
  * @filename: the filename of the device
  * @error: return location for a #GError, or %NULL
  *
@@ -509,8 +468,8 @@ ManetteDevice *
 manette_device_new (const gchar  *filename,
                     GError      **error)
 {
-  ManetteDevice *self = NULL;
-  GIOChannel *channel;
+  g_autoptr (ManetteDevice) self = NULL;
+  g_autoptr (GIOChannel) channel = NULL;
   gint buttons_number;
   gint axes_number;
   guint i;
@@ -523,11 +482,10 @@ manette_device_new (const gchar  *filename,
   if (self->fd < 0) {
     g_set_error (error,
                  G_FILE_ERROR,
-                 G_FILE_ERROR_FAILED,
+                 g_file_error_from_errno (errno),
                  "Unable to open “%s”: %s",
                  filename,
                  strerror (errno));
-    g_object_unref (self);
 
     return NULL;
   }
@@ -536,11 +494,10 @@ manette_device_new (const gchar  *filename,
   if (libevdev_set_fd (self->evdev_device, self->fd) < 0) {
     g_set_error (error,
                  G_FILE_ERROR,
-                 G_FILE_ERROR_FAILED,
+                 g_file_error_from_errno (errno),
                  "Evdev is unable to open “%s”: %s",
                  filename,
                  strerror (errno));
-    g_object_unref (self);
 
     return NULL;
   }
@@ -548,10 +505,9 @@ manette_device_new (const gchar  *filename,
   if (!is_game_controller (self->evdev_device)) {
     g_set_error (error,
                  G_FILE_ERROR,
-                 G_FILE_ERROR_NXIO,
+                 G_FILE_ERROR_FAILED,
                  "“%s” is not a game controller.",
                  filename);
-    g_object_unref (self);
 
     return NULL;
   }
@@ -560,17 +516,17 @@ manette_device_new (const gchar  *filename,
 
   // Poll the events in the main loop.
   channel = g_io_channel_unix_new (self->fd);
-  self->event_source_id = (glong) g_io_add_watch (channel, G_IO_IN, poll_events, self);
+  self->event_source_id = (glong) g_io_add_watch (channel, G_IO_IN, (GIOFunc) poll_events, self);
   buttons_number = 0;
 
   // Initialize the axes buttons and hats.
   for (i = BTN_JOYSTICK; i < KEY_MAX; i++)
-    if (libevdev_has_event_code (self->evdev_device, (guint) EV_KEY, i)) {
+    if (has_key (self->evdev_device, i)) {
       self->key_map[i - BTN_MISC] = (guint8) buttons_number;
       buttons_number++;
     }
   for (i = BTN_MISC; i < BTN_JOYSTICK; i++)
-    if (libevdev_has_event_code (self->evdev_device, (guint) EV_KEY, i)) {
+    if (has_key (self->evdev_device, i)) {
       self->key_map[i - BTN_MISC] = (guint8) buttons_number;
       buttons_number++;
     }
@@ -584,7 +540,7 @@ manette_device_new (const gchar  *filename,
 
       continue;
     }
-    if (libevdev_has_event_code (self->evdev_device, (guint) EV_ABS, i)) {
+    if (has_abs (self->evdev_device, i)) {
       const struct input_absinfo *absinfo;
 
       absinfo = libevdev_get_abs_info (self->evdev_device, i);
@@ -596,9 +552,7 @@ manette_device_new (const gchar  *filename,
     }
   }
 
-  g_io_channel_unref (channel);
-
-  return self;
+  return g_steal_pointer (&self);
 }
 
 /**
@@ -665,7 +619,9 @@ manette_device_get_name (ManetteDevice *self)
  * manette_device_get_product_id:
  * @self: a #ManetteDevice
  *
- * Gets the device's product ID.
+ * Gets the device's product ID. You can find some product IDs defined in the
+ * kernel's code, in drivers/hid/hid-ids.h. Just note that there isn't all
+ * devices there, but sufficiently enough most of the time.
  *
  * Returns: the product ID of @self
  */
@@ -681,7 +637,9 @@ manette_device_get_product_id (ManetteDevice *self)
  * manette_device_get_vendor_id:
  * @self: a #ManetteDevice
  *
- * Gets the device's vendor ID.
+ * Gets the device's vendor ID. You can find some vendor IDs defined in the
+ * kernel's code, in drivers/hid/hid-ids.h. Just note that there isn't all
+ * devices there, but sufficiently enough most of the time.
  *
  * Returns: the vendor ID of @self
  */
@@ -698,6 +656,7 @@ manette_device_get_vendor_id (ManetteDevice *self)
  * @self: a #ManetteDevice
  *
  * Gets the device's bustype ID.
+ * This corresponds to BUS_* as defined in linux/input.h
  *
  * Returns: the bustype ID of @self
  */
@@ -725,17 +684,21 @@ manette_device_get_version_id (ManetteDevice *self)
   return libevdev_get_id_version (self->evdev_device);
 }
 
-// FIXME documentation
+/**
+ * manette_device_set_mapping:
+ * @self: a #ManetteDevice
+ * @mapping: a #ManetteMapping
+ *
+ * Associate @mapping to @self to map its hardware events into standard gamepad
+ * ones.
+ */
 void
 manette_device_set_mapping (ManetteDevice  *self,
                             ManetteMapping *mapping)
 {
   g_return_if_fail (MANETTE_IS_DEVICE (self));
 
-  if (self->mapping != NULL)
-    g_object_unref (self->mapping);
-
-  self->mapping = mapping ? g_object_ref (mapping) : NULL;
+  g_set_object (&self->mapping, mapping);
 }
 
 /**
@@ -750,17 +713,14 @@ gboolean
 manette_device_has_user_mapping (ManetteDevice *self)
 {
   const gchar *guid;
-  ManetteMappingManager *mapping_manager;
-  gboolean has_user_mapping;
+  g_autoptr (ManetteMappingManager) mapping_manager = NULL;
 
   g_return_val_if_fail (MANETTE_IS_DEVICE (self), FALSE);
 
   guid = manette_device_get_guid (self);
   mapping_manager = manette_mapping_manager_new ();
-  has_user_mapping = manette_mapping_manager_has_user_mapping (mapping_manager, guid);
-  g_object_unref (mapping_manager);
 
-  return has_user_mapping;
+  return manette_mapping_manager_has_user_mapping (mapping_manager, guid);
 }
 
 /**
@@ -776,7 +736,7 @@ manette_device_save_user_mapping (ManetteDevice *self,
 {
   const gchar *guid;
   const gchar *name;
-  ManetteMappingManager *mapping_manager;
+  g_autoptr (ManetteMappingManager) mapping_manager = NULL;
 
   g_return_if_fail (MANETTE_IS_DEVICE (self));
   g_return_if_fail (mapping_string != NULL);
@@ -788,7 +748,6 @@ manette_device_save_user_mapping (ManetteDevice *self,
                                         guid,
                                         name,
                                         mapping_string);
-  g_object_unref (mapping_manager);
 }
 
 /**
@@ -801,16 +760,23 @@ void
 manette_device_remove_user_mapping (ManetteDevice *self)
 {
   const gchar *guid;
-  ManetteMappingManager *mapping_manager;
+  g_autoptr (ManetteMappingManager) mapping_manager = NULL;
 
   g_return_if_fail (MANETTE_IS_DEVICE (self));
 
   guid = manette_device_get_guid (self);
   mapping_manager = manette_mapping_manager_new ();
   manette_mapping_manager_delete_mapping (mapping_manager, guid);
-  g_object_unref (mapping_manager);
 }
 
+/**
+ * manette_device_has_rumble:
+ * @self: a #ManetteDevice
+ *
+ * Gets whether @self supports rumble.
+ *
+ * Returns: whether @self supports rumble
+ */
 gboolean
 manette_device_has_rumble (ManetteDevice *self)
 {
@@ -827,6 +793,20 @@ manette_device_has_rumble (ManetteDevice *self)
   return TRUE;
 }
 
+/**
+ * manette_device_rumble:
+ * @self: a #ManetteDevice
+ * @strong_magnitude: the magnitude for the heavy motor
+ * @weak_magnitude: the magnitude for the light motor
+ * @milliseconds: the rumble effect play time in milliseconds
+ *
+ * Make @self rumble during @milliseconds milliseconds, with the heavy and light
+ * motors rumbling at their respectively defined magnitudes.
+ *
+ * The duration cannot exceed 32767 milliseconds.
+ *
+ * Returns: whether the rumble effect was played
+ */
 gboolean
 manette_device_rumble (ManetteDevice *self,
                        guint16        strong_magnitude,
@@ -836,6 +816,7 @@ manette_device_rumble (ManetteDevice *self,
   struct input_event event;
 
   g_return_val_if_fail (MANETTE_IS_DEVICE (self), FALSE);
+  g_return_val_if_fail (milliseconds <= G_MAXINT16, FALSE);
 
   self->rumble_effect.u.rumble.strong_magnitude = strong_magnitude;
   self->rumble_effect.u.rumble.weak_magnitude = weak_magnitude;
