@@ -12,12 +12,11 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MANETTE_EVENT_H
-#define MANETTE_EVENT_H
+#pragma once
 
 #if !defined(__MANETTE_INSIDE__) && !defined(MANETTE_COMPILATION)
 # error "Only <libmanette.h> can be included directly."
@@ -41,6 +40,7 @@ typedef union  _ManetteEvent ManetteEvent;
  * @MANETTE_EVENT_BUTTON_RELEASE: a button has been released
  * @MANETTE_EVENT_ABSOLUTE: an absolute axis has been moved
  * @MANETTE_EVENT_HAT: a hat axis has been moved
+ * @MANETTE_LAST_EVENT: the number of event types
  *
  * Specifies the type of the event.
  */
@@ -77,5 +77,3 @@ gboolean manette_event_get_hat (const ManetteEvent *self,
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (ManetteEvent, manette_event_free)
 
 G_END_DECLS
-
-#endif /* MANETTE_EVENT_H */
